@@ -1,5 +1,6 @@
 use rayon::prelude::*;
 use reqwest::Url;
+use std::collections::HashSet;
 use tools::{build_client, collect_links, share_same_domain};
 
 mod app;
@@ -18,8 +19,14 @@ fn main() {
         .parse::<i8>()
         .expect("Cannot parse depth argument");
     let client = build_client(proxy, insecure_proxy, user_agent);
+    let mut shown_links: HashSet<String> = HashSet::new();
     let links = collect_links(&client, &url);
-    links.iter().for_each(|link| println!("{}", link));
+    links.iter().for_each(|link| {
+        if !shown_links.contains(link) {
+            println!("{}", link);
+            shown_links.insert(link.clone());
+        }
+    });
     while depth > 0 {
         let links = links
             .par_iter()
@@ -27,7 +34,12 @@ fn main() {
             .filter(|link| no_domain_filter || share_same_domain(&url, link))
             .flat_map(|link| collect_links(&client, &link))
             .collect::<Vec<String>>();
-        links.iter().for_each(|link| println!("{}", link));
+        links.iter().for_each(|link| {
+            if !shown_links.contains(link) {
+                println!("{}", link);
+                shown_links.insert(link.clone());
+            }
+        });
         depth -= 1;
     }
 }
